function varargout = popul(varargin)
% POPUL M-file for popul.fig
%      POPUL, by itself, creates a new POPUL or raises the existing
%      singleton*.
%
%      H = POPUL returns the handle to a new POPUL or the handle to
%      the existing singleton*.
%
%      POPUL('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in POPUL.M with the given input arguments.
%
%      POPUL('Property','Value',...) creates a new POPUL or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before popul_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to popul_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help popul

% Last Modified by GUIDE v2.5 05-Mar-2012 22:30:57

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @popul_OpeningFcn, ...
                   'gui_OutputFcn',  @popul_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before popul is made visible.
function popul_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to popul (see VARARGIN)

% Choose default command line output for popul
handles.output = hObject;

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes popul wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = popul_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on slider movement.
function r=slider1_Callback(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%én részem%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
r=get(hObject, 'Value');
%k=slider2_Callback(hObject, eventdata, handles);
%k=sl1;
k=0.5;
%r=sl2;
[t,x]=ode45(@(t,x)populatio(t,x,r,k), [0 30], k/10);
plot(handles.axes1,t,x(:,1),'r')
ylim(handles.axes1,[0,1.2]);
r
k
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider


% --- Executes during object creation, after setting all properties.
function slider1_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end

% --- Executes on slider movement.
function k=slider2_Callback(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%én részem%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
k=get(hObject, 'Value');
%r=slider1_Callback(hObject, eventdata, handles);
%r=sl2;
%k=sl1;
r=0.5;
[t,x]=ode45(@(t,x)populatio(t,x,r,k), [0 30], k/10);
plot(handles.axes1,t,x(:,1),'r')
ylim(handles.axes1,[0,1.2]);
r
k
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider


% --- Executes during object creation, after setting all properties.
function slider2_CreateFcn(hObject, eventdata, handles)
% hObject    handle to slider2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on button press in pushbutton1.
function pushbutton1_Callback(hObject, eventdata, handles)
% hObject    handle to pushbutton1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

%én részem%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
r=slider1_Callback(hObject, eventdata, handles);

k=slider2_Callback(hObject, eventdata, handles);

%r=sl2;
%k=sl1;
[t,x]=ode45(@(t,x)populatio(t,x,r,k), [0 30], k/10);
plot(handles.axes1,t,x(:,1),'r')
ylim(handles.axes1,[0,1.2]);
r
k
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

